Given /^they have arrived$/ do |table|
  puts table.raw
end
